local modsettings = {}

local _log = commonapi.utils.logPrep("commonapi.ui.modsettings")
local _utils = commonapi.utils
local _ = _utils._t
local ui = commonapi.ui;


local ModListWindow = require("commonapi.ui.ModListWindow")
local ModSettingsWindow = require("commonapi.ui.ModSettingsWindow")

local serializeSettingsData = ModSettingsWindow.serializeSettingsData

function modsettings.exportActiveMods()
	local activeMods = {}

	local mods = commonapi.mods.getLoaded()
	local hstrings = {
		"--[[",
		"Created by CommonAPI "..commonapi.version,
		"",
	}

	if (#mods < 1) then
		ui.msgbox("modlist_exportempty", _("Modlist is empty"), _("Modlist export") )
		return
	end

	for modid, entry in pairs( mods ) do
		local data = entry["data"] or {}

		local tpfid = string.gsub(entry.id, "_(%d+)$", "")
		local activeMod = {
			tpfid,
			entry.version[1],
			modId = entry.id,
			version = entry.version
		}
		if (data.info ~= nil) then
			local info = data.info
			if (info.tfnetId ~= nil) then
				activeMod.tfnetId = info.tfnetId
			end
			if (info.steamId ~= nil) then
				activeMod.steamId = info.steamId
			end
		end
		activeMods[#activeMods+1] = activeMod

		hstrings[#hstrings+1] = entry.id.."\t"..entry.version[1].."."..entry.version[2].."\t("..entry.name..")"
	end
	hstrings[#hstrings+1] = ""
	hstrings[#hstrings+1] = "count: ".. #activeMods
	hstrings[#hstrings+1] = "--]]"

	local header = table.concat(hstrings, "\n")
	local serData = header.."\n\nreturn "..serializeSettingsData(activeMods, "").."\n"

	local filename = commonapi._info.path .. "activemodlist.lua"
	local fh = io.open(filename, "w")
	if (fh) then
		fh:write(serData)
		fh:close()
	end
	_log("Exported active mod list to "..filename)

	ui.msgbox("modlist_exportok", "Exported active mod list to:\n"..filename, _("Modlist export") )
end


function modsettings.importActiveMods()
	local env = {}
	local inmodlist
	local filename = commonapi._info.path .. "activemodlist.lua"

	setmetatable(env, {__index=_G})
	luafnModList, err = loadfile(filename, "bt", env)
	if (luafnModList == nil) then
		return
	end

	inmodlist = luafnModList()
	if (type(inmodlist) ~= "table") then
		return
	end

	local _getByIdAny = commonapi.mods._getByIdAny
	local modlist = {}

	for i, entry in ipairs( inmodlist ) do
		local modid = entry[1]
		local version = entry[2]
		if (modid ~= nil and version ~= nil) then

			local modentry = _getByIdAny(modid.."_"..version)
			if (modentry == nil) then
				modentry = _getByIdAny(modid)
			end
			if (modentry ~= nil) then
				local tpfid = string.gsub(modentry.id, "_(%d+)$", "")
				local folder, fmodid = string.match(modentry.path, "([^/@]+)/([^/]+)/$")

				if (folder == "446800") then
					tpfid = "*"..tpfid
				end
				if (folder == "staging_area") then
					tpfid = "?"..tpfid
				end
				modlist[#modlist+1] = { tpfid, modentry.version[1] }
			end
		end
	end
	--commonapi.dmp(modlist)
	commonapi._native.setActiveModList(modlist)

	ui.msgbox("modlist_importok", "Imported from\n"..filename, _("Modlist import") )
end




local function menucallback()
	ModListWindow.create()
end

local function reloadcallback()
	package.loaded["commonapi.ui.modsettings"] = nil
	print("Reload callback called")
	local modsettings = require "commonapi.ui.modsettings"
	modsettings.run()
end


function modsettings.run()
	ui.createModMenuEntry('modsettings_open', _("Mod settings"), menucallback)

--	ui.createModMenuEntry('modsettings_reload', "Reload Mod Settings", reloadcallback)
if (CommonAPILuaState == true) then
	ui.createModMenuEntry('modsettings_export', _("Modlist export"), modsettings.exportActiveMods)
	ui.createModMenuEntry('modsettings_import', _("Modlist import"), modsettings.importActiveMods)
end
	local modlisterrorwindow = require "commonapi.ui.ModListErrorWindow"
	modlisterrorwindow.run()
end


function modsettings._showCommonAPISettings()
	_log("_showCommonAPISettings")

	local env = {
		data = function()
			return {}
		end,
		["_"] = commonapi.utils._t
	}

	local modentry = commonapi.mods._createModEntry("eis_os_commonapi_1", commonapi._info.path, env)
	local win = ModSettingsWindow.createByModEntry(modentry)
	win:open()
end
return modsettings